#ifndef WIDGET_H
#define WIDGET_H

#include <QtCore>
#include <QtGui>
#include "qemaemo5dynamichomescreenwidget.h"

#include <QWidget>
#include <QPixmap>
#include <QGridLayout>
#include <QToolButton>


class QPaintEvent;
class QSvgRenderer;
class QResizeEvent;

class Widget : public QeMaemo5DynamicHomescreenWidget
{
    Q_OBJECT
public:
    explicit Widget(QWidget *parent = 0);

public slots:
    void GetProg (QString file);
    void showSettingsDialog();
    void loadProgs();
    void desktop1();
    void desktop2();
    void desktop3();
    void desktop4();
    void desktop5();
    void desktop6();
    void desktop7();
    void desktop8();
    void desktop9();
    void desktop10();

private:
    QGridLayout *layout;
    QToolButton *buttons[9];

protected:
    virtual void paintEvent(QPaintEvent *e);

};

#endif
